pub struct GenericLineItem { /* private fields */ }Expand description
A metadata item.
This struct holds a metadata item, which is a key-value pair with an optional comment.
Usage
This struct is not meant to be used directly. Instead, use the crate::GenericImageRef
struct and associated methods to insert new metadata items, or to get existing
metadata items.
Valid Types
The valid types for the metadata value are:
u8|u16|u32|u64i8|i16|i32|i64f32|f64ColorSpacestd::time::Duration|chrono::DateTime<Utc>String|&str
The metadata values are encapsulated in a type-erased enum GenericValue.
Note
- The metadata key is case-insensitive and is stored as an uppercase string.
- When saving to a FITS file, the metadata comment may be truncated.
- Metadata of type
std::time::Durationorchrono::DateTime<Utc>is stored as two consecutive metadata items, split into seconds and nanoseconds, with keys suffixed_Sand_NS, plus a convenient base card (f64seconds for aDuration, an ISO-8601 string for a timestamp).
Implementations