pub trait FitsWrite {
// Required method
fn write_fits(
&self,
path: &Path,
compress: FitsCompression,
overwrite: bool,
) -> Result<PathBuf, FitsError>;
}Available on crate feature
fitsio only.Expand description
Trait for writing objects to FITS files.
Required Methods
Sourcefn write_fits(
&self,
path: &Path,
compress: FitsCompression,
overwrite: bool,
) -> Result<PathBuf, FitsError>
fn write_fits( &self, path: &Path, compress: FitsCompression, overwrite: bool, ) -> Result<PathBuf, FitsError>
Write the image, with metadata, to a FITS file.
Arguments
path: The path to write the FITS file to.compress: The compression algorithm to use (FitsCompression).overwrite: Whether to overwrite the file if it already exists.
Returns
The path to the written FITS file.
Errors
This function returns errors from the FITS library if the file could not be written.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".